Internals
=========

This section explores the different parts of how this plugin is implemented.

.. toctree::
    :hidden:

    hook
    plugin
    config
    reports
    store
    dependencies
    actions
